<?php
/* $Id: views_handler_field_qtc_views_chat_link.inc,v 1.1.2.4 2010/06/27 23:30:17 quiptime Exp $ */

/**
 * @file views_handler_field_qtc_views_chat_link.inc
 *
 * QTChat Views chat link handler.
 */

/**
 * Views field handler for the "QTChat Views" chat link.
 */
class views_handler_field_qtc_views_chat_link extends views_handler_field {
  function query() {
    if (!isset($this->view->field['name'])) {
      $this->query->add_field('users', 'name');
    }
    if (!isset($this->view->field['uid'])) {
      if ($this->view->base_table == 'node') {
        $this->query->add_field('users', 'uid');
      }
    }

    if (!isset($this->view->field['realname']) && module_exists('realname')) {
      if ($this->view->base_table == 'users') {
        $this->query->add_field('realname', 'realname');
      }
    }

    $this->query->add_field('users', 'access');
  }

  function option_definition() {
    $options = parent::option_definition();

    $options['link_info'] = array();
    $options['link_text'] = array('default' => 'Chat with user', 'translatable' => TRUE);

    return $options;
  }

  /**
   * Add the link text to options form.
   */
  function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);
    
    $form['link_info'] = array(
      '#type' => 'markup',
      '#value' => '<div class="form-item">'. t('The link is displayed only<br />has the corresponding user the permission <a href="!url">access qtchat</a>.', array('!url' => url('admin/user/permissions', array('fragment' => 'module-qtc')))) .'</div>',
      '#weight' => -2,
    );

    $form['link_text'] = array(
      '#type' => 'select',
      '#title' => 'Link text',
      '#description' => 'Select a link text.',
      '#options' => _views_chat_link_text_options(),
      '#default_value' => $this->options['link_text'],
      '#weight' => -1,
    );
    // Remove unneeded form elements.
    unset($form['override']);
    unset($form['alter']);
    unset($form['empty_zero']);
  }

  function element_type() {
    return 'div';
  }

  function render($values) {
    global $user;

    $link = '';

    if ($user->uid != $values->uid && user_access('access qtchat', $user)) {
      $chat_user = user_load(array('uid' => $values->uid));

      if (user_access('access qtchat', $user)) {
        $link_text = _views_chat_link_text_options();
        $last = time() - $values->users_access;
        $time_diff = variable_get('qtc_online_status_time', 900);

        $realname = $values->realname_realname ? $values->realname_realname : $values->users_name;
        
        // Build the chat invite link.
        if ($last < $time_diff) {
          $link = '<a class="qtc-chat-invite" onclick="javascript:chatWith(\''. $values->uid .'\', \''. $values->users_name .'\', \''. $realname .'\')" href="javascript:void(0)">'. $link_text[$this->options['link_text']] .'</a>';
        }
      }
    }

    return $link;
  }
}

/**
 * Get the link text variants.
 *
 * @return array
 *   The link text options.
 */
function _views_chat_link_text_options() {
  return array(
           1 => t('Chat with user'),
           2 => t('Invite to chat'),
           3 => t('Chat'),
         );
}
